@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011, 2012, 2013 German A. Arias
+   Copyright (C) 2009, 2010, 2011, 2012, 2013, 2015 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -44,7 +44,6 @@
     {
       objects = floor(code/50);
       decision = YES;
-      [self postModuleNotification];
     }
   else
     {
@@ -120,7 +119,7 @@
   
   if (allow)
     {  
-      [[NSCursor openHandCursor] set];
+      [[NSCursor pointingHandCursor] set];
       image = [sender image];
       objectCode = [sender tag];
       newObject = YES;
@@ -183,6 +182,12 @@
       count += 1;
       newObject = NO;
       image = nil;
+
+      // If this is the first element added, set the corresponding menu.
+      if (count == 1)
+	{
+	  [self postModuleNotification];
+	}
     }
   // Add the moved element at clicked cell.
   else if ((moveObject) && ([sender image] == nil))
@@ -202,7 +207,7 @@
       [sender setImage: nil];
       [sender setTag: 0];
       [sender setToolTip: @""];
-      [[NSCursor closedHandCursor] set];
+      [[NSCursor pointingHandCursor] set];
       moveObject = YES;
     }
   // Delete the element at clicked cell.
@@ -241,10 +246,10 @@
   moveObject = NO;
   image = nil;
   [[NSCursor arrowCursor] set];
-  
-  if (count == 0)
-    {
-      objects = -1;
+
+  if (count == 0)	 
+    {	 
+      objects = -1;	 
     }
 }
 
@@ -308,7 +313,7 @@
 	  [botonCell setTitle: @""];
 	  [botonCell setImagePosition: NSImageOnly];
 	  [botonCell setBordered: NO];
-	  [botonCell addToolTipRect: NSMakeRect(0, 0, width*50, height*50)
+	  [botonCell addToolTipRect: NSMakeRect(0, 0, 50, 50)
 			      owner: self
 			   userData: nil];
 	  [self addSubview: botonCell];
