@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2010, 2011, 2012, 2013 German A. Arias
+   Copyright (C) 2010, 2011, 2012, 2013, 2014 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -26,19 +26,6 @@
 #import <gsl/gsl_rng.h>
 #import "FLStaticsRigidBodies.h"
 
-static int varG;
-static double gravityDat;
-static NSMutableDictionary *dictionary;
-static NSMutableArray *vars, *forceObjs, *forceTypes, *resultants,
-  *codObjects, *namesObjects, *codSolids, *namesSolids, *typeElements,
-  *solidForceTypes, *codElemResul, *codResul, *codOthers;
-static NSString *gravityVar;
-
-struct parameters
-{
-  double a;
-  double b;
-};
 
 static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
 {
@@ -47,6 +34,23 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   double gf;
   NSNumber *object;
   NSEnumerator *enumerator;
+
+  // Get properties of FL object.
+  FLStaticsRigidBodies *FLObj = (__bridge FLStaticsRigidBodies *)(p);
+
+  NSInteger varG = FLObj->varG;
+  NSString *gravityVar = FLObj->gravityVar;
+  double gravityDat = FLObj->gravityDat;
+  NSMutableArray *vars = FLObj->vars;
+  NSMutableArray *forceObjs = FLObj->forceObjs;
+  NSMutableArray *codObjects = FLObj->codObjects;
+  NSMutableArray *codSolids = FLObj->codSolids;
+  NSMutableArray *typeElements = FLObj->typeElements;
+  NSMutableArray *solidForceTypes = FLObj->solidForceTypes;
+  NSMutableArray *codResul = FLObj->codResul;
+  NSMutableArray *codOthers = FLObj->codOthers;
+  NSMutableDictionary *dictionary = FLObj->dictionary;
+  // ----------------------------------------
   
   if (varG == 1)
     {
@@ -949,8 +953,6 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   NSString *message;
   size_t iter;
   
-  struct parameters p = {1.0, 1.0};
-  
   gsl_vector *x = gsl_vector_alloc (n);
   int countRes = 0;
   id anObj;
@@ -970,7 +972,7 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   
   do
     {
-      gsl_multiroot_function f = {&buildSystem, n, &p};
+      gsl_multiroot_function f = {&buildSystem, n, (__bridge void *)(self)};
       iter = 0;
       for (k = 0; k < nvar; k++)
 	{
@@ -1487,32 +1489,19 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   NSBundle *messages;
   self = [super init];
   
-  vars = [NSMutableArray array];
-  [vars retain];
-  codObjects = [NSMutableArray array];
-  [codObjects retain];
-  namesObjects = [NSMutableArray array];
-  [namesObjects retain];
-  codSolids = [NSMutableArray array];
-  [codSolids retain];
-  namesSolids = [NSMutableArray array];
-  [namesSolids retain];
-  typeElements = [NSMutableArray array];
-  [typeElements retain];
-  forceObjs = [NSMutableArray array];
-  [forceObjs retain];
-  forceTypes = [NSMutableArray array];
-  [forceTypes retain];
-  resultants = [NSMutableArray array];
-  [resultants retain];
-  solidForceTypes = [NSMutableArray array];
-  [solidForceTypes retain];
-  codElemResul = [NSMutableArray array];
-  [codElemResul retain];
-  codResul = [NSMutableArray array];
-  [codResul retain];
-  codOthers = [NSMutableArray array];
-  [codOthers retain];
+  vars = [NSMutableArray new];
+  codObjects = [NSMutableArray new];
+  namesObjects = [NSMutableArray new];
+  codSolids = [NSMutableArray new];
+  namesSolids = [NSMutableArray new];
+  typeElements = [NSMutableArray new];
+  forceObjs = [NSMutableArray new];
+  forceTypes = [NSMutableArray new];
+  resultants = [NSMutableArray new];
+  solidForceTypes = [NSMutableArray new];
+  codResul = [NSMutableArray new];
+  codOthers = [NSMutableArray new];
+  dictionary = [NSMutableDictionary new];
   
   // Build array of messages
   messages = [NSBundle mainBundle];
@@ -1559,7 +1548,7 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   height = [self chalkboardHeight];
   totalCells = width*height - 1;
   
-  dictionary = [[NSMutableDictionary alloc] initWithDictionary: list];
+  [dictionary setDictionary: list];
   keys = [[NSArray alloc] initWithArray: [list allKeys]];
   enumerator = [keys objectEnumerator];
   
@@ -2571,7 +2560,6 @@ static int buildSystem (const gsl_vector *v, void *p, gsl_vector *func)
   [forceTypes release];
   [resultants release];
   [solidForceTypes release];
-  [codElemResul release];
   [codResul release];
   [codOthers release];
   [errors release];
