@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011, 2012, 2013 German A. Arias
+   Copyright (C) 2009, 2010, 2011, 2012, 2013, 2015 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -61,4 +61,7 @@
 
 - (void) tableView: (NSTableView*)aTableView willDisplayCell: (id)aCell
     forTableColumn: (NSTableColumn*)aTableColumn row: (NSInteger)rowIndex;
+
+// Delegate for contextual menu.
+- (void) menuNeedsUpdate: (NSMenu*)menu;
 @end
